diff --git a/pandora_agents/win32/ChangeLog b/pandora_agents/win32/ChangeLog
index 55532a0e7b..2b55b79275 100644
--- a/pandora_agents/win32/ChangeLog
+++ b/pandora_agents/win32/ChangeLog
@@ -1,3 +1,9 @@
+2010-04-23  Ramon Novoa  <rnovoa@artica.es>
+
+	* modules/pandora_module_inventory.cc: Fixed a couple of XML tags.
+
+	* installer/pandora.mpi: Added the vbs scripts to the installer.
+
 2010-04-21  Ramon Novoa  <rnovoa@artica.es>
 
 	* main.cc: Updated headers after tinyxml removal.
diff --git a/pandora_agents/win32/installer/pandora.mpi b/pandora_agents/win32/installer/pandora.mpi
index 28c7cadb90..ab164ddf02 100755
--- a/pandora_agents/win32/installer/pandora.mpi
+++ b/pandora_agents/win32/installer/pandora.mpi
@@ -292,6 +292,8 @@ File ::955A9B5D-775D-4C4B-07C6-1E457A3AEF04 -type dir -name text-base -active 0
 File ::57A504DC-687C-F126-8B39-6A70F43C156A -name cmp.exe -parent 6E5B73B7-8B81-48D7-BF49-59D8D92FB830
 File ::B71D3B59-A60B-6C21-76D4-292FA73C1613 -name getreg.exe -parent 6E5B73B7-8B81-48D7-BF49-59D8D92FB830
 File ::DB77AA43-D4B7-239C-0F48-52502E17D4DC -name sort.exe -parent 6E5B73B7-8B81-48D7-BF49-59D8D92FB830
+File ::7B1652FD-0C02-13A8-BAA8-1B6F8BB257A5 -name df.vbs -parent 6E5B73B7-8B81-48D7-BF49-59D8D92FB830
+File ::558D0D7E-2D41-EA8A-325D-27FA08CE8B69 -name ps.vbs -parent 6E5B73B7-8B81-48D7-BF49-59D8D92FB830
 File ::EE3962D4-48B8-4715-B986-40794679FC89 -name ../bin/libcurl.dll -parent 946FC43B-0E32-4C38-86EF-4F9252C67E16
 File ::0C6E0B9F-E094-42D4-9376-EAC5E3E475F7 -name ../bin/libeay32.dll -parent 946FC43B-0E32-4C38-86EF-4F9252C67E16
 File ::03A7EA5A-D6FC-4427-B35C-0288C07813B6 -filemethod {Never overwrite files} -name ../bin/pandora_agent.conf -parent 946FC43B-0E32-4C38-86EF-4F9252C67E16
diff --git a/pandora_agents/win32/modules/pandora_module_inventory.cc b/pandora_agents/win32/modules/pandora_module_inventory.cc
index 00e696de87..e399096c76 100644
--- a/pandora_agents/win32/modules/pandora_module_inventory.cc
+++ b/pandora_agents/win32/modules/pandora_module_inventory.cc
@@ -325,9 +325,9 @@ Pandora_Module_Inventory::getXml() {
 			
 			if (current_module != prev_module) {
 				
 				/* Close the previous datalist */
 				if (prev_module != "") {
-					module_xml += "\t\t\t</datalist>\n";
+					module_xml += "\t\t\t</datalist>\n\t\t</inventory_module>\n";
 				}
 				module_xml += "\t\t<inventory_module>\n\t\t\t<name><![CDATA[";
 				module_xml += data->getDataOrigin();
@@ -353,6 +353,13 @@ Pandora_Module_Inventory::getXml() {
 			
 			prev_module = current_module;
 		}
+		
+		/* Close the last datalist and module_inventory */
+		module_xml += "\t\t\t</datalist>\n\t\t</inventory_module>\n";
+		
+		/* Close inventory */
+		module_xml += "\t</inventory>\n";
+
 	}
 	
 	/* Clean up */
@@ -325,9 +325,9 @@ Pandora_Module_Inventory::getXml() {
 			if (current_module != prev_module) {
 				
-				/* Close the previous datalist */
+				/* Close the previous datalist and inventory_module*/
 				if (prev_module != "") {